# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PrinterStateEnum(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    OPERATIONAL = "Operational"
    PAUSED = "Paused"
    CANCELLING = "Cancelling"
    PRINTING = "Printing"
    PAUSING = "Pausing"
    SDREADY = "sdReady"
    ERROR = "Error"
    READYPRINTER_READY = "ReadyPrinter Ready"
    CLOSEDORERROR = "closedOrError"
    OFFLINE = "Offline"
    OPENING_SERIAL_CONNECTION = "Opening serial connection"
    CONNECTION = "Connection"
    RESUMING = "Resuming"
    FINISHING = "Finishing"
    PRINTERSTATECHANGED = "PrinterStateChanged"
    CONNECTED = "Connected"
    DISCONNECTED = "Disconnected"
    PRINTERRESET = "PrinterReset"
    FIRMWAREDATA = "FirmwareData"

    allowable_values = [OPERATIONAL, PAUSED, CANCELLING, PRINTING, PAUSING, SDREADY, ERROR, READYPRINTER_READY, CLOSEDORERROR, OFFLINE, OPENING_SERIAL_CONNECTION, CONNECTION, RESUMING, FINISHING, PRINTERSTATECHANGED, CONNECTED, DISCONNECTED, PRINTERRESET, FIRMWAREDATA]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """PrinterStateEnum - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterStateEnum):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterStateEnum):
            return True

        return self.to_dict() != other.to_dict()
