# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DeviceState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'deleted': 'datetime',
        'status': 'StatusEnum',
        'command': 'DeviceStateCommandEnum',
        'ansible_facts': 'dict(str, object)',
        'ansible_extra_vars': 'dict(str, object)',
        'created_dt': 'datetime',
        'device': 'int'
    }

    attribute_map = {
        'id': 'id',
        'deleted': 'deleted',
        'status': 'status',
        'command': 'command',
        'ansible_facts': 'ansible_facts',
        'ansible_extra_vars': 'ansible_extra_vars',
        'created_dt': 'created_dt',
        'device': 'device'
    }

    def __init__(self, id=None, deleted=None, status=None, command=None, ansible_facts=None, ansible_extra_vars=None, created_dt=None, device=None, local_vars_configuration=None):  # noqa: E501
        """DeviceState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._deleted = None
        self._status = None
        self._command = None
        self._ansible_facts = None
        self._ansible_extra_vars = None
        self._created_dt = None
        self._device = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if deleted is not None:
            self.deleted = deleted
        if status is not None:
            self.status = status
        if command is not None:
            self.command = command
        if ansible_facts is not None:
            self.ansible_facts = ansible_facts
        if ansible_extra_vars is not None:
            self.ansible_extra_vars = ansible_extra_vars
        if created_dt is not None:
            self.created_dt = created_dt
        self.device = device

    @property
    def id(self):
        """Gets the id of this DeviceState.  # noqa: E501


        :return: The id of this DeviceState.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceState.


        :param id: The id of this DeviceState.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def deleted(self):
        """Gets the deleted of this DeviceState.  # noqa: E501


        :return: The deleted of this DeviceState.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this DeviceState.


        :param deleted: The deleted of this DeviceState.  # noqa: E501
        :type deleted: datetime
        """

        self._deleted = deleted

    @property
    def status(self):
        """Gets the status of this DeviceState.  # noqa: E501


        :return: The status of this DeviceState.  # noqa: E501
        :rtype: StatusEnum
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeviceState.


        :param status: The status of this DeviceState.  # noqa: E501
        :type status: StatusEnum
        """

        self._status = status

    @property
    def command(self):
        """Gets the command of this DeviceState.  # noqa: E501


        :return: The command of this DeviceState.  # noqa: E501
        :rtype: DeviceStateCommandEnum
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this DeviceState.


        :param command: The command of this DeviceState.  # noqa: E501
        :type command: DeviceStateCommandEnum
        """

        self._command = command

    @property
    def ansible_facts(self):
        """Gets the ansible_facts of this DeviceState.  # noqa: E501


        :return: The ansible_facts of this DeviceState.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._ansible_facts

    @ansible_facts.setter
    def ansible_facts(self, ansible_facts):
        """Sets the ansible_facts of this DeviceState.


        :param ansible_facts: The ansible_facts of this DeviceState.  # noqa: E501
        :type ansible_facts: dict(str, object)
        """

        self._ansible_facts = ansible_facts

    @property
    def ansible_extra_vars(self):
        """Gets the ansible_extra_vars of this DeviceState.  # noqa: E501


        :return: The ansible_extra_vars of this DeviceState.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._ansible_extra_vars

    @ansible_extra_vars.setter
    def ansible_extra_vars(self, ansible_extra_vars):
        """Sets the ansible_extra_vars of this DeviceState.


        :param ansible_extra_vars: The ansible_extra_vars of this DeviceState.  # noqa: E501
        :type ansible_extra_vars: dict(str, object)
        """

        self._ansible_extra_vars = ansible_extra_vars

    @property
    def created_dt(self):
        """Gets the created_dt of this DeviceState.  # noqa: E501


        :return: The created_dt of this DeviceState.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this DeviceState.


        :param created_dt: The created_dt of this DeviceState.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def device(self):
        """Gets the device of this DeviceState.  # noqa: E501


        :return: The device of this DeviceState.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this DeviceState.


        :param device: The device of this DeviceState.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceState):
            return True

        return self.to_dict() != other.to_dict()
