# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Release(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'ansible_extra_vars': 'AnsibleExtraVars',
        'created_dt': 'datetime',
        'release_channel': 'ReleaseChannelEnum'
    }

    attribute_map = {
        'id': 'id',
        'ansible_extra_vars': 'ansible_extra_vars',
        'created_dt': 'created_dt',
        'release_channel': 'release_channel'
    }

    def __init__(self, id=None, ansible_extra_vars=None, created_dt=None, release_channel=None, local_vars_configuration=None):  # noqa: E501
        """Release - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ansible_extra_vars = None
        self._created_dt = None
        self._release_channel = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.ansible_extra_vars = ansible_extra_vars
        if created_dt is not None:
            self.created_dt = created_dt
        if release_channel is not None:
            self.release_channel = release_channel

    @property
    def id(self):
        """Gets the id of this Release.  # noqa: E501


        :return: The id of this Release.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Release.


        :param id: The id of this Release.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def ansible_extra_vars(self):
        """Gets the ansible_extra_vars of this Release.  # noqa: E501


        :return: The ansible_extra_vars of this Release.  # noqa: E501
        :rtype: AnsibleExtraVars
        """
        return self._ansible_extra_vars

    @ansible_extra_vars.setter
    def ansible_extra_vars(self, ansible_extra_vars):
        """Sets the ansible_extra_vars of this Release.


        :param ansible_extra_vars: The ansible_extra_vars of this Release.  # noqa: E501
        :type ansible_extra_vars: AnsibleExtraVars
        """
        if self.local_vars_configuration.client_side_validation and ansible_extra_vars is None:  # noqa: E501
            raise ValueError("Invalid value for `ansible_extra_vars`, must not be `None`")  # noqa: E501

        self._ansible_extra_vars = ansible_extra_vars

    @property
    def created_dt(self):
        """Gets the created_dt of this Release.  # noqa: E501


        :return: The created_dt of this Release.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Release.


        :param created_dt: The created_dt of this Release.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def release_channel(self):
        """Gets the release_channel of this Release.  # noqa: E501


        :return: The release_channel of this Release.  # noqa: E501
        :rtype: ReleaseChannelEnum
        """
        return self._release_channel

    @release_channel.setter
    def release_channel(self, release_channel):
        """Sets the release_channel of this Release.


        :param release_channel: The release_channel of this Release.  # noqa: E501
        :type release_channel: ReleaseChannelEnum
        """

        self._release_channel = release_channel

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Release):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Release):
            return True

        return self.to_dict() != other.to_dict()
